[ooo-build-commit] .: patches/vba
Noel Power
noelp at kemper.freedesktop.org
Fri Feb 5 04:50:00 PST 2010
patches/vba/vba-container-controls.diff | 8 +++++---
1 file changed, 5 insertions(+), 3 deletions(-)
New commits:
commit 7f64d996c7bbca761d019e24e27c6da18e50dee2
Author: Noel Power <noel.power at novell.com>
Date: Fri Feb 5 12:49:38 2010 +0000
only allow embedded images to be selected for controls in 'document' Dialogs
* patches/vba/vba-container-controls.diff:
diff --git a/patches/vba/vba-container-controls.diff b/patches/vba/vba-container-controls.diff
index c3b9ddb..f997e6a 100644
--- a/patches/vba/vba-container-controls.diff
+++ b/patches/vba/vba-container-controls.diff
@@ -114,12 +114,14 @@ diff --git extensions/source/propctrlr/formcomponenthandler.cxx extensions/sourc
index b12854b..b34807f 100644
--- extensions/source/propctrlr/formcomponenthandler.cxx
+++ extensions/source/propctrlr/formcomponenthandler.cxx
-@@ -2765,7 +2765,7 @@ namespace pcr
+@@ -2765,7 +2765,8 @@ namespace pcr
aFileDlg.SetTitle(aStrTrans);
// non-linked images ( e.g. those located in the document
- // stream ) cannot *currently* be handled by openoffice basic dialogs.
+- // stream ) cannot *currently* be handled by openoffice basic dialogs.
++ // stream ) only if document is available
- bool bHandleNonLink = ( m_eComponentClass == eFormControl );
-+ bool bHandleNonLink = true;
++ Reference< XModel > xModel( impl_getContextDocument_nothrow() );
++ bool bHandleNonLink = xModel.is();
Reference< XFilePickerControlAccess > xController(aFileDlg.GetFilePicker(), UNO_QUERY);
DBG_ASSERT(xController.is(), "FormComponentPropertyHandler::impl_browseForImage_nothrow: missing the controller interface on the file picker!");
More information about the ooo-build-commit
mailing list